@@ -57,9 +57,9 @@ class MapTiles(ranaModule):
     self.images = [{}, {}] # the first dict contains normal image data, the second contains special tiles
     self.imagesLock = threading.RLock()
     self.threads = {}
-    self.threadlListCondition = threading.Condition(threading.Lock())
-    self.maxImagesInMemmory = 150 # to avoid a memory leak
-    self.imagesTrimmingAmmount = 30 # how many tiles to remove once the maximum is reached
+    self.threadListCondition = threading.Condition(threading.Lock())
+    self.maxImagesInMemory = 150 # to avoid a memory leak
+    self.imagesTrimmingAmount = 30 # how many tiles to remove once the maximum is reached
     self.loadRequestCStackSize = 10 # size for the circular loading request stack
     """so that trim does not run always run after adding a tile"""
     self.tileSide = 256 # by default, the tiles are squares, side=256
@@ -139,15 +139,15 @@ class MapTiles(ranaModule):
     layerType = layerInfo.get('type', 'png')
     tileData = self._storeTiles.getTileData(layerPrefix, z, x, y, layerType)
     if tileData:
-    #      print "got tile FROM disk CACHE"
+    #      print("got tile FROM disk CACHE")
       # tile was available from storage
       return tileData
 
-    #    print "download"
+    #    print("download")
     url = self.getTileUrl(x, y, z, layer)
-    #    print url
+    #    print(url)
     response = self._getConnPool(layer, url).get_url(url)
-    #    print "RESPONSE"
+    #    print("RESPONSE")
     tileData = response.data
 
     if tileData:
@@ -156,7 +156,7 @@ class MapTiles(ranaModule):
         tileFolder = self.modrana.paths.getMapFolderPath()
         filePath = os.path.join(tileFolder, self.getImagePath(x, y, z, layerPrefix, layerType))
         self._storeTiles.automaticStoreTile(tileData, layerPrefix, z, x, y, layerType, filePath)
-        #        print "STORED"
+        #        print("STORED")
         return tileData
       else:
         print("mapTiles: tile data returned by remote tileserver was not an image")
@@ -216,14 +216,14 @@ class MapTiles(ranaModule):
     if self.get('network', 'full') == 'full':
       filename = os.path.join(self._getTileFolderPath(), (self.getImagePath(x, y, z, layerPrefix, layerType)))
       # add tile download request
-      with self.threadlListCondition:
+      with self.threadListCondition:
         timestamp = time.time()
         request = (name, x, y, z, layer, layerPrefix, layerType, filename, timestamp)
 
         with self.downloadRequestPoolLock: # add a download request
           self.downloadRequestPool.append(request)
 
-        self.threadlListCondition.notifyAll() # wake up the download manager
+        self.threadListCondition.notifyAll() # wake up the download manager
 
   def tileInProgress(self, layer, z, x, y):
     """
@@ -276,12 +276,12 @@ class MapTiles(ranaModule):
   def tileDownloadManager(self):
     """this is a tile loading request consumer thread"""
     while True:
-      with self.threadlListCondition:
+      with self.threadListCondition:
         try:
           """
           wait for notification that there might be download requests or free download slots
           """
-          self.threadlListCondition.wait()
+          self.threadListCondition.wait()
           if self.shutdownAllThreads:
             print("\nmapTiles: automatic tile download management thread shutting down")
             break
@@ -332,30 +332,30 @@ class MapTiles(ranaModule):
               self.downloadRequestPool = cleanPool
         except Exception, e:
           print("exception in tile download manager thread:\n%s" % e)
-        #          traceback.print_exc()
+          #          traceback.print_exc()
 
-        #  def startTileLoadingThread(self):
-        #    """start the loading-request consumer thread"""
-        #    t = Thread(target=self.tileLoader, name='tile loading thread')
-        #    t.setDaemon(True) # we need that the worker dies with the program
-        #    t.start()
+          #  def startTileLoadingThread(self):
+          #    """start the loading-request consumer thread"""
+          #    t = Thread(target=self.tileLoader, name='tile loading thread')
+          #    t.setDaemon(True) # we need that the worker dies with the program
+          #    t.start()
 
-        #  def tileLoader(self):
-        #    """this is a tile loading request consumer thread"""
-        #    while True:
-        #      request = self.loadingNotifyQueue.get(block=True) # consume from this queue
-        #      if request == 'load':
-        #        # start processing loading requests from the stack
-        #        while(1):
-        #          (item,valid) = self.loadRequestCStack.popValid()
-        #          if valid:
-        #            (name, x, y, z, layer) = item
-        #            self.loadImage(name, x, y, z, layer)
-        #          else:
-        #            break # the stack is empty
-        #      elif request == 'shutdown':
-        #        print "\nmapTiles: tile loading thread shutting down"
-        #        break
+          #  def tileLoader(self):
+          #    """this is a tile loading request consumer thread"""
+          #    while True:
+          #      request = self.loadingNotifyQueue.get(block=True) # consume from this queue
+          #      if request == 'load':
+          #        # start processing loading requests from the stack
+          #        while(1):
+          #          (item,valid) = self.loadRequestCStack.popValid()
+          #          if valid:
+          #            (name, x, y, z, layer) = item
+          #            self.loadImage(name, x, y, z, layer)
+          #          else:
+          #            break # the stack is empty
+          #      elif request == 'shutdown':
+          #        print "\nmapTiles: tile loading thread shutting down"
+          #        break
 
   def _startIdleTileLoader(self):
     """add the tile loader as a gobject mainloop idle callback"""
@@ -397,33 +397,33 @@ class MapTiles(ranaModule):
       (name, path) = tile
       self.loadImageFromFile(path, name, type="special", dictIndex=1)
 
-    #  def _checkAutomaticTileDownloads(self):
-    #    """monitor if the automatic tile downloads finished and then remove them from the dictionary
-    #    (also automagically refreshes the screen once new tiles are available, even when not centered)"""
-    #
-    #
-    #    """seems that some added error handling in the download thread class can replace this,
-    #       but it left here for testing purposes"""
-    #    z = self.get('z', 15)
-    #    """when we change zoomlevel and the number of threads does not change,
-    #       we clear the threads set, this is useful, because:
-    #       * failed downloads don't accumulate and will be tried again when we visit this zoomlevel again
-    #       * tile downloads that don't actually exist (eq tiles from max+1 zoomlevel) don't accumulate
-    #       it is important to have the "self.threads" set empty when we are not downloading anything,
-    #       because otherwise we are wasting time on the "refresh on finished tile download" logic and also
-    #       the set could theoretically cause a memory leak if not periodically cleared from wrong items
-    #
-    #       this method was chosen instead of a timeout, because it would be hard to set a timeout,
-    #       that would work on GPRS and a fast connection
-    #    """
-    #    if self.oldZ != z:
-    ##      print "resetting z"
-    #      self.oldZ = z
-    #      if len(self.threads) == self.oldThreadCount:
-    #        print "clearing thread set"
-    #        self.threads = {}
-    #        self.oldThreadCount = len(self.threads)
-    #    self.oldThreadCount = len(self.threads)
+      #  def _checkAutomaticTileDownloads(self):
+      #    """monitor if the automatic tile downloads finished and then remove them from the dictionary
+      #    (also automagically refreshes the screen once new tiles are available, even when not centered)"""
+      #
+      #
+      #    """seems that some added error handling in the download thread class can replace this,
+      #       but it left here for testing purposes"""
+      #    z = self.get('z', 15)
+      #    """when we change zoomlevel and the number of threads does not change,
+      #       we clear the threads set, this is useful, because:
+      #       * failed downloads don't accumulate and will be tried again when we visit this zoomlevel again
+      #       * tile downloads that don't actually exist (eq tiles from max+1 zoomlevel) don't accumulate
+      #       it is important to have the "self.threads" set empty when we are not downloading anything,
+      #       because otherwise we are wasting time on the "refresh on finished tile download" logic and also
+      #       the set could theoretically cause a memory leak if not periodically cleared from wrong items
+      #
+      #       this method was chosen instead of a timeout, because it would be hard to set a timeout,
+      #       that would work on GPRS and a fast connection
+      #    """
+      #    if self.oldZ != z:
+      ##      print "resetting z"
+      #      self.oldZ = z
+      #      if len(self.threads) == self.oldThreadCount:
+      #        print "clearing thread set"
+      #        self.threads = {}
+      #        self.oldThreadCount = len(self.threads)
+      #    self.oldThreadCount = len(self.threads)
 
   def beforeDraw(self):
     """we need to synchronize centering with map redraw,
@@ -436,7 +436,7 @@ class MapTiles(ranaModule):
     if self.get('reportTileCacheStatus', False): # TODO: set to False by default
       print("** tile cache status report **")
       print("threads: %d, images: %d, special tiles: %d, downloadRequestPool:%d" % (
-      len(self.threads), len(self.images[0]), len(self.images[1]), len(self.downloadRequestPool)))
+        len(self.threads), len(self.images[0]), len(self.images[1]), len(self.downloadRequestPool)))
 
   def drawMap(self, cr):
     """Draw map tile images"""
@@ -449,9 +449,9 @@ class MapTiles(ranaModule):
           function in place of the default one"""
 
       singleGetName = self.getTileName
+      ratio = self.get('transpRatio', "0.5,1").split(',') # get the transparency ratio
+      (alphaOver, alphaBack) = (float(ratio[0]), float(ratio[1])) # convert it to floats
       if overlay:
-        ratio = self.get('transpRatio', "0.5,1").split(',') # get the transparency ratio
-        (alphaOver, alphaBack) = (float(ratio[0]), float(ratio[1])) # convert it to floats
         layer1 = self.get('layer', 'mapnik')
         layer2 = self.get('layer2', 'cycle')
         layerInfo = ((layer1, alphaBack), (layer2, alphaOver))
@@ -587,7 +587,7 @@ class MapTiles(ranaModule):
                           self.removeImageFromMemmory(nameBack)
                           self.removeImageFromMemmory(nameOver)
                           # cache the combined image
-                          self.storeInMemmory(combinedImage, name, "composite")
+                          self.storeInMemory(combinedImage, name, "composite")
                           # draw the composite image
                           drawImage(cr, combinedImage, x1, y1, scale)
                         else:
@@ -604,18 +604,18 @@ class MapTiles(ranaModule):
               if gui.getShowRedrawTime():
                 print "currently visible tiles: %d/%d" % (visibleCounter, wTiles * hTiles)
 
-              #            cr.set_source_rgba(0,1,0,0.5)
-              #            cr.move_to(*p1.as_tuple())
-              #            cr.line_to(*p2.as_tuple())
-              #            cr.line_to(*p4.as_tuple())
-              #            cr.line_to(*p3.as_tuple())
-              #            cr.line_to(*p1.as_tuple())
-              #            cr.close_path()
-              #            cr.fill()
-              #
-              #            cr.set_source_rgba(1,0,0,1)
-              #            cr.rectangle(scP.x-10,scP.y-10,20,20)
-              #            cr.fill()
+                #            cr.set_source_rgba(0,1,0,0.5)
+                #            cr.move_to(*p1.as_tuple())
+                #            cr.line_to(*p2.as_tuple())
+                #            cr.line_to(*p4.as_tuple())
+                #            cr.line_to(*p3.as_tuple())
+                #            cr.line_to(*p1.as_tuple())
+                #            cr.close_path()
+                #            cr.fill()
+                #
+                #            cr.set_source_rgba(1,0,0,1)
+                #            cr.rectangle(scP.x-10,scP.y-10,20,20)
+                #            cr.fill()
 
         else:
           # draw without rotation
@@ -665,7 +665,7 @@ class MapTiles(ranaModule):
                         self.removeImageFromMemmory(nameBack)
                         self.removeImageFromMemmory(nameOver)
                         # cache the combined image
-                        self.storeInMemmory(combinedImage, name, "composite")
+                        self.storeInMemory(combinedImage, name, "composite")
                         # draw the composite image
                         drawImage(cr, combinedImage, x1, y1, scale)
                       else: # on or more tiles not usable
@@ -691,10 +691,10 @@ class MapTiles(ranaModule):
         # try to start the idle tile loader
         self._startIdleTileLoader()
 
-      #    except Queue.Full:
-      #      """as we use the queue as a notification mechanism, we don't actually need to
-      #      process all the "load" notifications """
-      #      pass
+        #    except Queue.Full:
+        #      """as we use the queue as a notification mechanism, we don't actually need to
+        #      process all the "load" notifications """
+        #      pass
 
     except Exception, e:
       print("mapTiles: exception while drawing the map layer: %s" % e)
@@ -771,7 +771,7 @@ class MapTiles(ranaModule):
     sprint("loading tile %s" % name)
 
     # first, is it already in the process of being downloaded?
-    with self.threadlListCondition:
+    with self.threadListCondition:
       if name in self.threads.keys():
         sprint("tile is being downloaded")
         if not self.threads[name].finished:
@@ -797,7 +797,7 @@ class MapTiles(ranaModule):
        False means loading the tile from file to pixbuf failed"""
     if pixbuf:
       start2 = time.clock()
-      self.storeInMemmory(self.pixbufToCairoImageSurface(pixbuf), name)
+      self.storeInMemory(self.pixbufToCairoImageSurface(pixbuf), name)
       if debug:
         storageType = self.get('tileStorageType', 'files')
         sprint("tile loaded from local storage (%s) in %1.2f ms" % (storageType, (1000 * (time.clock() - start1))))
@@ -814,7 +814,7 @@ class MapTiles(ranaModule):
       # use threads
       """the thread list condition is used to signalize to the download manager,
       that here is a new download request"""
-      with self.threadlListCondition:
+      with self.threadListCondition:
         timestamp = time.time()
         request = (name, x, y, z, layer, layerPrefix, layerType, filename, timestamp)
 
@@ -826,7 +826,7 @@ class MapTiles(ranaModule):
         with self.downloadRequestPoolLock: # add a download request
           self.downloadRequestPool.append(request)
 
-        self.threadlListCondition.notifyAll() # wake back the download manager
+        self.threadListCondition.notifyAll() # wake back the download manager
     else:
       sprint("automatic tile download disabled - not starting download")
 
@@ -847,7 +847,7 @@ class MapTiles(ranaModule):
     ct2.set_source_pixbuf(pixbuf, 0, 0)
     ct2.paint()
     ''' surface now contains the image in a Cairo surface '''
-    self.storeInMemmory(surface, name, type, expireTimestamp, dictIndex)
+    self.storeInMemory(surface, name, type, expireTimestamp, dictIndex)
 
   def filePath2Pixbuf(self, filePath):
     """return a pixbuf for a given filePath"""
@@ -858,7 +858,7 @@ class MapTiles(ranaModule):
       print("the tile image is corrupted nad/or there are no tiles for this zoomlevel, exception:\n%s" % e)
       return False
 
-  def storeInMemmory(self, surface, name, type="normal", expireTimestamp=None, dictIndex=0):
+  def storeInMemory(self, surface, name, type="normal", expireTimestamp=None, dictIndex=0):
     """store a given image surface in the memory image cache
        dictIndex = 0 -> normal map tiles + tile specific error tiles
        dictIndex = 1 -> special tiles that exist in only once in memory and are drawn directly
@@ -871,7 +871,7 @@ class MapTiles(ranaModule):
 
       """ check cache size,
       if there are too many images, delete them """
-      if len(self.images[0]) > self.maxImagesInMemmory:
+      if len(self.images[0]) > self.maxImagesInMemory:
         self.trimCache()
         # new tile available, make redraw request TODO: what overhead does this create ?
       self._tileLoadedNotify(type)
@@ -893,15 +893,15 @@ class MapTiles(ranaModule):
     """to avoid a memory leak, the maximum size of the image cache is fixed
        when we reach the maximum size, we start removing images,
        starting from the oldest ones
-       we an amount of images specified in imagesTrimmingAmmount,
+       we an amount of images specified in imagesTrimmingAmount,
        so that trim does not run every time an image is added to a full cache
        -> only the normal image cache needs trimming (images[0]),
        as the special image cache (images[1]) is just created once and not updated dynamically
-       NOTE: the storeInMemmory method already locked images, so we don't have to
+       NOTE: the storeInMemory method already locked images, so we don't have to
        """
-    trimmingAmmount = self.imagesTrimmingAmmount
+    trimmingAmount = self.imagesTrimmingAmount
     imagesLength = len(self.images[0])
-    if trimmingAmmount >= imagesLength:
+    if trimmingAmount >= imagesLength:
       """
       this means that the trimming amount was set higher,
       than current length of the cache
@@ -911,7 +911,7 @@ class MapTiles(ranaModule):
       self.images[0] = {}
     else:
       oldestKeys = sorted(self.images[0], key=lambda image: self.images[0][image][1]['addedTimestamp'])[
-                   0:trimmingAmmount]
+                   0:trimmingAmount]
       for key in oldestKeys:
         del self.images[0][key]
 
@@ -939,7 +939,7 @@ Therefore we use it as default."""
   def imageName(self, x, y, z, layer):
     """Get a unique name for a tile image 
     (suitable for use as part of filenames, dictionary keys, etc)"""
-    return("%s_%d_%d_%d" % (layer, z, x, y))
+    return "%s_%d_%d_%d" % (layer, z, x, y)
 
   def getImagePath(self, x, y, z, prefix, extension):
     """Get a unique name for a tile image
@@ -950,14 +950,14 @@ Therefore we use it as default."""
   def getImageFolder(self, x, z, prefix):
     """Get a unique name for a tile image
     (suitable for use as part of filenames, dictionary keys, etc)"""
-    return "%s/%d/%d" % (prefix, z, x)
+    return os.path.join(prefix, str(z), str(x))
 
   def _getTileFolderPath(self):
     """helper function that returns path to the tile folder"""
     return self.mapFolderPath
 
   def imageY(self, z, extension):
-    return ('%d.%s') % (z, extension)
+    return '%d.%s' % (z, extension)
 
   def getTileUrl(self, x, y, z, layer):
     """Return url for given tile coordinates and layer"""
@@ -1000,8 +1000,8 @@ Therefore we use it as default."""
     #      """the tile loading thread is demonic, so it will be still killed in the end"""
     #      pass
     # notify the automatic tile download manager thread about the shutdown
-    with self.threadlListCondition:
-      self.threadlListCondition.notifyAll()
+    with self.threadListCondition:
+      self.threadListCondition.notifyAll()
 
   class TileDownloader(Thread):
     """Downloads an image (in a thread)"""
@@ -1022,7 +1022,7 @@ Therefore we use it as default."""
 
     def run(self):
       try:
-        self.downloadTile(\
+        self.downloadTile(
           self.name,
           self.x,
           self.y,
@@ -1032,11 +1032,11 @@ Therefore we use it as default."""
         self.finished = 1
 
       # something is wrong with the server or url
-      except urllib2.HTTPError, e:
+      except urllib2.HTTPError:
         if self.useImageSurface:
           tileDownloadFailedSurface = self.callback.images[1]['tileDownloadFailed'][0]
           expireTimestamp = time.time() + 10
-          self.callback.storeInMemmory(tileDownloadFailedSurface, self.name, 'semiPermanentError', expireTimestamp)
+          self.callback.storeInMemory(tileDownloadFailedSurface, self.name, 'semiPermanentError', expireTimestamp)
           """
           like this, when tile download fails due to a http error,
           the error tile is loaded instead
@@ -1050,7 +1050,7 @@ Therefore we use it as default."""
         if self.useImageSurface:
           tileNetworkErrorSurface = self.callback.images[1]['tileNetworkError'][0]
           expireTimestamp = time.time() + 10
-          self.callback.storeInMemmory(tileNetworkErrorSurface, self.name, 'error',
+          self.callback.storeInMemory(tileNetworkErrorSurface, self.name, 'error',
             expireTimestamp) # retry after 10 seconds
           """ as not to DOS the system when we temporarily loose internet connection or other such error occurs,
                we load a temporary error tile with expiration timestamp instead of the tile image
@@ -1068,18 +1068,18 @@ Therefore we use it as default."""
         self.removeSelf()
 
     def removeSelf(self):
-      with self.callback.threadlListCondition:
+      with self.callback.threadListCondition:
         # try to remove its own instance from the thread list, so that the instance could be garbage collected
         if self.name in self.callback.threads.keys():
           del self.callback.threads[self.name]
           """notify the download manager that a download slot is now free"""
-          self.callback.threadlListCondition.notifyAll()
+          self.callback.threadListCondition.notifyAll()
 
     def printErrorMessage(self, e):
       url = self.callback.getTileUrl(self.x, self.y, self.z, self.layer)
       print("mapTiles: download thread reports error")
       print("** we were doing this, when an exception occurred:")
-      print("** downloading tile: x:%d,y:%d,z:%d, layer:%s, filename:%s, url: %s" % (\
+      print("** downloading tile: x:%d,y:%d,z:%d, layer:%s, filename:%s, url: %s" % (
         self.x,
         self.y,
         self.z,
@@ -1121,11 +1121,11 @@ Therefore we use it as default."""
         ct2.set_source_pixbuf(pl.get_pixbuf(), 0, 0)
         ct2.paint()
         ''' surface now contains the image in a Cairo surface '''
-        self.callback.storeInMemmory(surface, name)
+        self.callback.storeInMemory(surface, name)
         # like this, corrupted tiles should not get past the pixbuf loader and be stored
       else:
         # cache the raw data
-        self.callback.storeInMemmory(content, name)
+        self.callback.storeInMemory(content, name)
 
       m = self.callback._storeTiles
       if m:
@@ -1133,7 +1133,7 @@ Therefore we use it as default."""
 
 # modified from: http://www.maptiler.org/google-maps-coordinates-tile-bounds-projection/globalmaptiles.py (GPL)
 def quadTree(tx, ty, zoom ):
-  "Converts OSM type tile coordinates to Microsoft QuadTree"
+  """Converts OSM type tile coordinates to Microsoft QuadTree"""
 
   quadKey = ""
   #		ty = (2**zoom - 1) - ty
